# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "FETUS",
    "MOTHER"
]

DICT_SUB_STRUCTURES = {
    "FETUS":[
        'Body 1',
        'Body 2',
        'Cords 1',
        'Cords 2',
        'Ventricles 1',
        'Ventricles 2'],
        
    "MOTHER":[
        'Blader',
        'Placenta',
        'Ribs',
        'Uterus',
    ]
}